You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ju...@apache.org on 2015/10/16 13:54:14 UTC

svn commit: r1708966 - in /subversion/branches/move-tracking-2/subversion: include/private/ libsvn_delta/ libsvn_ra/ svnmover/

Author: julianfoad
Date: Fri Oct 16 11:54:13 2015
New Revision: 1708966

URL: http://svn.apache.org/viewvc?rev=1708966&view=rev
Log:
On the 'move-tracking-2' branch: Rename 'revision_root' to 'txn'.

* subversion/include/private/svn_branch.h
  (svn_branch_txn_t,
   svn_branch_txn_create,
   svn_branch_txn_get_branches,
   svn_branch_txn_get_branch_by_id,
   svn_branch_txn_new_eid,
   svn_branch_txn_finalize_eids,
   svn_branch_txn_delete_branch,
   svn_branch_txn_parse,
   svn_branch_txn_serialize): Rename from *_revision_root_*.
  Rename struct members and function arguments similarly.

* subversion/include/private/svn_branch_repos.h,
  subversion/include/private/svn_editor3e.h,
  subversion/include/private/svn_ra_private.h,
  subversion/libsvn_delta/branch.c,
  subversion/libsvn_delta/branch_nested.c,
  subversion/libsvn_delta/branch_repos.c,
  subversion/libsvn_delta/compat3e.c,
  subversion/libsvn_ra/ra_loader.c,
  subversion/svnmover/svnmover.c
  Track these changes, and make similar changes nearly everywhere.

Modified:
    subversion/branches/move-tracking-2/subversion/include/private/svn_branch.h
    subversion/branches/move-tracking-2/subversion/include/private/svn_branch_repos.h
    subversion/branches/move-tracking-2/subversion/include/private/svn_editor3e.h
    subversion/branches/move-tracking-2/subversion/include/private/svn_ra_private.h
    subversion/branches/move-tracking-2/subversion/libsvn_delta/branch.c
    subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_nested.c
    subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_repos.c
    subversion/branches/move-tracking-2/subversion/libsvn_delta/compat3e.c
    subversion/branches/move-tracking-2/subversion/libsvn_ra/ra_loader.c
    subversion/branches/move-tracking-2/subversion/svnmover/svnmover.c

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_branch.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_branch.h?rev=1708966&r1=1708965&r2=1708966&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/include/private/svn_branch_repos.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_branch_repos.h Fri Oct 16 11:54:13 2015
@@ -52,19 +52,19 @@ svn_branch_repos_create(apr_pool_t *resu
  */
 svn_error_t *
 svn_branch_repos_add_revision(svn_branch_repos_t *repos,
-                              svn_branch_revision_root_t *rev_root);
+                              svn_branch_txn_t *rev_root);
 
 /* Return a pointer to revision REVNUM of the repository REPOS.
  */
-struct svn_branch_revision_root_t *
+struct svn_branch_txn_t *
 svn_branch_repos_get_revision(const svn_branch_repos_t *repos,
                               svn_revnum_t revnum);
 
 /* Return the revision root that represents the base revision (or,
  * potentially, txn) of the revision or txn REV_ROOT.
  */
-svn_branch_revision_root_t *
-svn_branch_repos_get_base_revision_root(svn_branch_revision_root_t *rev_root);
+svn_branch_txn_t *
+svn_branch_repos_get_base_revision_root(svn_branch_txn_t *rev_root);
 
 /* Set *BRANCH_P to the branch found in REPOS : REVNUM : BRANCH_ID.
  *

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_editor3e.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_editor3e.h?rev=1708966&r1=1708965&r2=1708966&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/include/private/svn_editor3e.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_editor3e.h Fri Oct 16 11:54:13 2015
@@ -1126,7 +1126,7 @@ svn_editor3__ev3_from_delta_for_commit(
                         svn_editor3__shim_connector_t **shim_connector,
                         const svn_delta_editor_t *deditor,
                         void *dedit_baton,
-                        svn_branch_revision_root_t *branching_txn,
+                        svn_branch_txn_t *branching_txn,
                         const char *repos_root_url,
                         svn_editor3__shim_fetch_func_t fetch_func,
                         void *fetch_baton,
@@ -1219,7 +1219,7 @@ svn_editor3__ev3_from_delta_for_update(
                         svn_update_editor3_t **editor_p,
                         const svn_delta_editor_t *deditor,
                         void *dedit_baton,
-                        svn_branch_revision_root_t *branching_txn,
+                        svn_branch_txn_t *branching_txn,
                         const char *repos_root_url,
                         const char *base_repos_relpath,
                         svn_editor3__shim_fetch_func_t fetch_func,
@@ -1247,7 +1247,7 @@ svn_editor3__delta_from_ev3_for_update(
  */
 svn_error_t *
 svn_editor3_in_memory(svn_editor3_t **editor_p,
-                      svn_branch_revision_root_t *branching_txn,
+                      svn_branch_txn_t *branching_txn,
                       svn_editor3__shim_fetch_func_t fetch_func,
                       void *fetch_baton,
                       apr_pool_t *result_pool);

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_ra_private.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_ra_private.h?rev=1708966&r1=1708965&r2=1708966&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/include/private/svn_ra_private.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_ra_private.h Fri Oct 16 11:54:13 2015
@@ -311,7 +311,7 @@ svn_ra__replay_ev2(svn_ra_session_t *ses
 /* Load branching info.
  */
 svn_error_t *
-svn_ra_load_branching_state(svn_branch_revision_root_t **branching_txn_p,
+svn_ra_load_branching_state(svn_branch_txn_t **branching_txn_p,
                             svn_editor3__shim_fetch_func_t *fetch_func,
                             void **fetch_baton,
                             svn_ra_session_t *session,
@@ -327,7 +327,7 @@ svn_ra_load_branching_state(svn_branch_r
  */
 svn_error_t *
 svn_ra_get_commit_editor_ev3(svn_ra_session_t *session,
-                             svn_branch_revision_root_t **edit_txn_p,
+                             svn_branch_txn_t **edit_txn_p,
                              svn_editor3_t **editor,
                              apr_hash_t *revprop_table,
                              svn_commit_callback2_t commit_callback,

Modified: subversion/branches/move-tracking-2/subversion/libsvn_delta/branch.c
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/libsvn_delta/branch.c?rev=1708966&r1=1708965&r2=1708966&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/libsvn_delta/branch.c (original)
+++ subversion/branches/move-tracking-2/subversion/libsvn_delta/branch.c Fri Oct 16 11:54:13 2015
@@ -37,7 +37,7 @@
 
 /* Is EID allocated (no matter whether an element with this id exists)? */
 #define EID_IS_ALLOCATED(branch, eid) \
-  ((eid) >= (branch)->rev_root->first_eid && (eid) < (branch)->rev_root->next_eid)
+  ((eid) >= (branch)->txn->first_eid && (eid) < (branch)->txn->next_eid)
 
 #define IS_BRANCH_ROOT_EID(branch, eid) \
   ((eid) == (branch)->element_tree->root_eid)
@@ -55,28 +55,28 @@ branch_state_pool_get(svn_branch_state_t
   return apr_hash_pool_get(branch->element_tree->e_map);
 }
 
-svn_branch_revision_root_t *
-svn_branch_revision_root_create(svn_branch_repos_t *repos,
-                                svn_revnum_t rev,
-                                svn_revnum_t base_rev,
-                                apr_pool_t *result_pool)
-{
-  svn_branch_revision_root_t *rev_root
-    = apr_pcalloc(result_pool, sizeof(*rev_root));
-
-  rev_root->repos = repos;
-  rev_root->rev = rev;
-  rev_root->base_rev = base_rev;
-  rev_root->branches = svn_array_make(result_pool);
-  return rev_root;
+svn_branch_txn_t *
+svn_branch_txn_create(svn_branch_repos_t *repos,
+                      svn_revnum_t rev,
+                      svn_revnum_t base_rev,
+                      apr_pool_t *result_pool)
+{
+  svn_branch_txn_t *txn
+    = apr_pcalloc(result_pool, sizeof(*txn));
+
+  txn->repos = repos;
+  txn->rev = rev;
+  txn->base_rev = base_rev;
+  txn->branches = svn_array_make(result_pool);
+  return txn;
 }
 
 int
-svn_branch_txn_new_eid(svn_branch_revision_root_t *rev_root)
+svn_branch_txn_new_eid(svn_branch_txn_t *txn)
 {
-  int eid = (rev_root->first_eid < 0) ? rev_root->first_eid - 1 : -2;
+  int eid = (txn->first_eid < 0) ? txn->first_eid - 1 : -2;
 
-  rev_root->first_eid = eid;
+  txn->first_eid = eid;
   return eid;
 }
 
@@ -144,7 +144,7 @@ branch_finalize_eids(svn_branch_state_t
 }
 
 svn_error_t *
-svn_branch_txn_finalize_eids(svn_branch_revision_root_t *txn,
+svn_branch_txn_finalize_eids(svn_branch_txn_t *txn,
                              apr_pool_t *scratch_pool)
 {
   int n_txn_eids = (-1) - txn->first_eid;
@@ -172,21 +172,21 @@ svn_branch_txn_finalize_eids(svn_branch_
 }
 
 apr_array_header_t *
-svn_branch_revision_root_get_branches(svn_branch_revision_root_t *rev_root,
-                                      apr_pool_t *result_pool)
+svn_branch_txn_get_branches(svn_branch_txn_t *txn,
+                            apr_pool_t *result_pool)
 {
-  return apr_array_copy(result_pool, rev_root->branches);
+  return apr_array_copy(result_pool, txn->branches);
 }
 
 svn_branch_state_t *
-svn_branch_revision_root_get_branch_by_id(const svn_branch_revision_root_t *rev_root,
-                                          const char *branch_id,
-                                          apr_pool_t *scratch_pool)
+svn_branch_txn_get_branch_by_id(const svn_branch_txn_t *txn,
+                                const char *branch_id,
+                                apr_pool_t *scratch_pool)
 {
   SVN_ITER_T(svn_branch_state_t) *bi;
   svn_branch_state_t *branch = NULL;
 
-  for (SVN_ARRAY_ITER(bi, rev_root->branches, scratch_pool))
+  for (SVN_ARRAY_ITER(bi, txn->branches, scratch_pool))
     {
       svn_branch_state_t *b = bi->val;
 
@@ -213,7 +213,7 @@ assert_branch_state_invariants(const svn
   apr_hash_index_t *hi;
 
   assert(branch->bid);
-  assert(branch->rev_root);
+  assert(branch->txn);
   assert(branch->element_tree);
   assert(branch->element_tree->e_map);
 
@@ -230,14 +230,14 @@ svn_branch_state_t *
 svn_branch_state_create(const char *bid,
                         svn_branch_rev_bid_t *predecessor,
                         int root_eid,
-                        svn_branch_revision_root_t *rev_root,
+                        svn_branch_txn_t *txn,
                         apr_pool_t *result_pool)
 {
   svn_branch_state_t *b = apr_pcalloc(result_pool, sizeof(*b));
 
   b->bid = apr_pstrdup(result_pool, bid);
   b->predecessor = svn_branch_rev_bid_dup(predecessor, result_pool);
-  b->rev_root = rev_root;
+  b->txn = txn;
   b->element_tree = svn_element_tree_create(NULL, root_eid, result_pool);
   assert_branch_state_invariants(b, result_pool);
   return b;
@@ -537,7 +537,7 @@ svn_branch_map_add_subtree(svn_branch_st
   /* Get a new EID for the root element, if not given. */
   if (to_eid == -1)
     {
-      to_eid = svn_branch_txn_new_eid(to_branch->rev_root);
+      to_eid = svn_branch_txn_new_eid(to_branch->txn);
     }
 
   /* Create the new subtree root element */
@@ -596,7 +596,7 @@ svn_branch_instantiate_elements(svn_bran
 
 svn_branch_state_t *
 svn_branch_add_new_branch(const char *bid,
-                          svn_branch_revision_root_t *rev_root,
+                          svn_branch_txn_t *txn,
                           svn_branch_rev_bid_t *predecessor,
                           int root_eid,
                           apr_pool_t *scratch_pool)
@@ -605,32 +605,31 @@ svn_branch_add_new_branch(const char *bi
 
   SVN_ERR_ASSERT_NO_RETURN(root_eid != -1);
 
-  new_branch = svn_branch_state_create(bid, predecessor, root_eid, rev_root,
-                                       rev_root->branches->pool);
+  new_branch = svn_branch_state_create(bid, predecessor, root_eid, txn,
+                                       txn->branches->pool);
 
-  SVN_ARRAY_PUSH(rev_root->branches) = new_branch;
+  SVN_ARRAY_PUSH(txn->branches) = new_branch;
 
   return new_branch;
 }
 
 void
-svn_branch_revision_root_delete_branch(
-                                svn_branch_revision_root_t *rev_root,
-                                svn_branch_state_t *branch,
-                                apr_pool_t *scratch_pool)
+svn_branch_txn_delete_branch(svn_branch_txn_t *txn,
+                             svn_branch_state_t *branch,
+                             apr_pool_t *scratch_pool)
 {
   SVN_ITER_T(svn_branch_state_t) *bi;
 
-  SVN_ERR_ASSERT_NO_RETURN(branch->rev_root == rev_root);
+  SVN_ERR_ASSERT_NO_RETURN(branch->txn == txn);
 
-  for (SVN_ARRAY_ITER(bi, rev_root->branches, scratch_pool))
+  for (SVN_ARRAY_ITER(bi, txn->branches, scratch_pool))
     {
       if (bi->val == branch)
         {
           SVN_DBG(("deleting branch b%s e%d",
                    svn_branch_get_id(bi->val, bi->iterpool),
                    bi->val->element_tree->root_eid));
-          svn_sort__array_delete(rev_root->branches, bi->i, 1);
+          svn_sort__array_delete(txn->branches, bi->i, 1);
           break;
         }
     }
@@ -761,7 +760,7 @@ svn_branch_id_unnest(const char **outer_
  */
 static svn_error_t *
 svn_branch_state_parse(svn_branch_state_t **new_branch,
-                       svn_branch_revision_root_t *rev_root,
+                       svn_branch_txn_t *txn,
                        svn_stream_t *stream,
                        apr_pool_t *result_pool,
                        apr_pool_t *scratch_pool)
@@ -775,7 +774,7 @@ svn_branch_state_parse(svn_branch_state_
   SVN_ERR(parse_branch_line(bid, &root_eid, &num_eids, &predecessor,
                             stream, scratch_pool, scratch_pool));
 
-  branch_state = svn_branch_state_create(bid, predecessor, root_eid, rev_root,
+  branch_state = svn_branch_state_create(bid, predecessor, root_eid, txn,
                                          result_pool);
 
   /* Read in the structure. Set the payload of each normal element to a
@@ -795,7 +794,7 @@ svn_branch_state_parse(svn_branch_state_
           svn_element_payload_t *payload;
           if (! is_subbranch)
             {
-              payload = svn_element_payload_create_ref(rev_root->rev, bid, eid,
+              payload = svn_element_payload_create_ref(txn->rev, bid, eid,
                                                        result_pool);
             }
           else
@@ -813,13 +812,13 @@ svn_branch_state_parse(svn_branch_state_
 }
 
 svn_error_t *
-svn_branch_revision_root_parse(svn_branch_revision_root_t **rev_root_p,
-                               svn_branch_repos_t *repos,
-                               svn_stream_t *stream,
-                               apr_pool_t *result_pool,
-                               apr_pool_t *scratch_pool)
+svn_branch_txn_parse(svn_branch_txn_t **txn_p,
+                     svn_branch_repos_t *repos,
+                     svn_stream_t *stream,
+                     apr_pool_t *result_pool,
+                     apr_pool_t *scratch_pool)
 {
-  svn_branch_revision_root_t *rev_root;
+  svn_branch_txn_t *txn;
   svn_revnum_t rev;
   int first_eid, next_eid;
   int num_branches;
@@ -837,22 +836,21 @@ svn_branch_revision_root_parse(svn_branc
              &num_branches);
   SVN_ERR_ASSERT(n == 4);
 
-  rev_root = svn_branch_revision_root_create(repos, rev, rev - 1,
-                                             result_pool);
-  rev_root->first_eid = first_eid;
-  rev_root->next_eid = next_eid;
+  txn = svn_branch_txn_create(repos, rev, rev - 1, result_pool);
+  txn->first_eid = first_eid;
+  txn->next_eid = next_eid;
 
   /* parse the branches */
   for (j = 0; j < num_branches; j++)
     {
       svn_branch_state_t *branch;
 
-      SVN_ERR(svn_branch_state_parse(&branch, rev_root, stream,
+      SVN_ERR(svn_branch_state_parse(&branch, txn, stream,
                                      result_pool, scratch_pool));
-      SVN_ARRAY_PUSH(rev_root->branches) = branch;
+      SVN_ARRAY_PUSH(txn->branches) = branch;
     }
 
-  *rev_root_p = rev_root;
+  *txn_p = txn;
   return SVN_NO_ERROR;
 }
 
@@ -918,26 +916,26 @@ svn_branch_state_serialize(svn_stream_t
 }
 
 svn_error_t *
-svn_branch_revision_root_serialize(svn_stream_t *stream,
-                                   svn_branch_revision_root_t *rev_root,
-                                   apr_pool_t *scratch_pool)
+svn_branch_txn_serialize(svn_stream_t *stream,
+                         svn_branch_txn_t *txn,
+                         apr_pool_t *scratch_pool)
 {
   SVN_ITER_T(svn_branch_state_t) *bi;
 
   SVN_ERR(svn_stream_printf(stream, scratch_pool,
                             "r%ld: eids %d %d "
                             "branches %d\n",
-                            rev_root->rev,
-                            rev_root->first_eid, rev_root->next_eid,
-                            rev_root->branches->nelts));
+                            txn->rev,
+                            txn->first_eid, txn->next_eid,
+                            txn->branches->nelts));
 
-  for (SVN_ARRAY_ITER(bi, rev_root->branches, scratch_pool))
+  for (SVN_ARRAY_ITER(bi, txn->branches, scratch_pool))
     {
       svn_branch_state_t *branch = bi->val;
 
       if (branch->predecessor && branch->predecessor->rev < 0)
         {
-          branch->predecessor->rev = rev_root->rev;
+          branch->predecessor->rev = txn->rev;
         }
 
       SVN_ERR(svn_branch_state_serialize(stream, bi->val, bi->iterpool));

Modified: subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_nested.c
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_nested.c?rev=1708966&r1=1708965&r2=1708966&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_nested.c (original)
+++ subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_nested.c Fri Oct 16 11:54:13 2015
@@ -47,8 +47,8 @@ svn_branch_get_outer_branch_and_eid(svn_
   if (outer_bid)
     {
       *outer_branch_p
-        = svn_branch_revision_root_get_branch_by_id(branch->rev_root, outer_bid,
-                                                    scratch_pool);
+        = svn_branch_txn_get_branch_by_id(branch->txn, outer_bid,
+                                          scratch_pool);
     }
 }
 
@@ -105,9 +105,8 @@ svn_branch_get_subbranch_at_eid(svn_bran
       const char *subbranch_id = svn_branch_id_nest(branch_id, eid,
                                                     scratch_pool);
 
-      return svn_branch_revision_root_get_branch_by_id(branch->rev_root,
-                                                       subbranch_id,
-                                                       scratch_pool);
+      return svn_branch_txn_get_branch_by_id(branch->txn, subbranch_id,
+                                             scratch_pool);
     }
   return NULL;
 }
@@ -132,9 +131,8 @@ svn_branch_get_immediate_subbranches(svn
           const char *subbranch_id
             = svn_branch_id_nest(branch_id, eid, scratch_pool);
           svn_branch_state_t *subbranch
-            = svn_branch_revision_root_get_branch_by_id(branch->rev_root,
-                                                        subbranch_id,
-                                                        scratch_pool);
+            = svn_branch_txn_get_branch_by_id(branch->txn, subbranch_id,
+                                              scratch_pool);
 
           SVN_ARRAY_PUSH(subbranches) = subbranch;
         }
@@ -233,7 +231,7 @@ svn_branch_instantiate_elements_r(svn_br
         new_branch_id = svn_branch_id_nest(to_branch->bid, this_outer_eid,
                                            bi->iterpool);
         new_branch = svn_branch_add_new_branch(new_branch_id,
-                                               to_branch->rev_root,
+                                               to_branch->txn,
                                                this_subtree->predecessor,
                                                this_subtree->tree->root_eid,
                                                bi->iterpool);

Modified: subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_repos.c
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_repos.c?rev=1708966&r1=1708965&r2=1708966&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_repos.c (original)
+++ subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_repos.c Fri Oct 16 11:54:13 2015
@@ -56,14 +56,14 @@ svn_branch_repos_create(apr_pool_t *resu
 
 svn_error_t *
 svn_branch_repos_add_revision(svn_branch_repos_t *repos,
-                              svn_branch_revision_root_t *rev_root)
+                              svn_branch_txn_t *rev_root)
 {
   APR_ARRAY_PUSH(repos->rev_roots, void *) = rev_root;
 
   return SVN_NO_ERROR;
 }
 
-struct svn_branch_revision_root_t *
+struct svn_branch_txn_t *
 svn_branch_repos_get_revision(const svn_branch_repos_t *repos,
                               svn_revnum_t revnum)
 {
@@ -71,8 +71,8 @@ svn_branch_repos_get_revision(const svn_
   return svn_array_get(repos->rev_roots, revnum);
 }
 
-svn_branch_revision_root_t *
-svn_branch_repos_get_base_revision_root(svn_branch_revision_root_t *rev_root)
+svn_branch_txn_t *
+svn_branch_repos_get_base_revision_root(svn_branch_txn_t *rev_root)
 {
   return svn_branch_repos_get_revision(rev_root->repos, rev_root->base_rev);
 }
@@ -84,15 +84,15 @@ svn_branch_repos_get_branch_by_id(svn_br
                                   const char *branch_id,
                                   apr_pool_t *scratch_pool)
 {
-  svn_branch_revision_root_t *rev_root;
+  svn_branch_txn_t *rev_root;
 
   if (revnum < 0 || revnum >= repos->rev_roots->nelts)
     return svn_error_createf(SVN_ERR_FS_NO_SUCH_REVISION, NULL,
                              _("No such revision %ld"), revnum);
 
   rev_root = svn_branch_repos_get_revision(repos, revnum);
-  *branch_p = svn_branch_revision_root_get_branch_by_id(rev_root, branch_id,
-                                                        scratch_pool);
+  *branch_p = svn_branch_txn_get_branch_by_id(rev_root, branch_id,
+                                              scratch_pool);
   if (! *branch_p)
     return svn_error_createf(SVN_ERR_BRANCHING, NULL,
                              _("Branch %s not found in r%ld"),

Modified: subversion/branches/move-tracking-2/subversion/libsvn_delta/compat3e.c
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/libsvn_delta/compat3e.c?rev=1708966&r1=1708965&r2=1708966&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/libsvn_delta/compat3e.c (original)
+++ subversion/branches/move-tracking-2/subversion/libsvn_delta/compat3e.c Fri Oct 16 11:54:13 2015
@@ -554,7 +554,7 @@ typedef struct ev3_from_delta_baton_t
   apr_hash_t *changes;
 
   /* The branching state on which the per-element API is working */
-  svn_branch_revision_root_t *edited_rev_root;
+  svn_branch_txn_t *txn;
 
   apr_pool_t *edit_pool;
 } ev3_from_delta_baton_t;
@@ -1032,7 +1032,7 @@ branch_in_rev_or_txn(svn_branch_state_t
   if (SVN_IS_VALID_REVNUM(src_el_rev->rev))
     {
       SVN_ERR(svn_branch_repos_get_branch_by_id(src_branch,
-                                                eb->edited_rev_root->repos,
+                                                eb->txn->repos,
                                                 src_el_rev->rev,
                                                 src_el_rev->bid,
                                                 result_pool));
@@ -1040,8 +1040,8 @@ branch_in_rev_or_txn(svn_branch_state_t
   else
     {
       *src_branch
-        = svn_branch_revision_root_get_branch_by_id(
-            eb->edited_rev_root, src_el_rev->bid, result_pool);
+        = svn_branch_txn_get_branch_by_id(
+            eb->txn, src_el_rev->bid, result_pool);
     }
 
   return SVN_NO_ERROR;
@@ -1115,7 +1115,7 @@ payload_resolve(svn_element_payload_t *p
     return SVN_NO_ERROR;
 
   SVN_ERR(payload_get_storage_pathrev(&storage, payload,
-                                      eb->edited_rev_root->repos,
+                                      eb->txn->repos,
                                       scratch_pool));
 
   SVN_ERR(eb->fetch_func(&payload->kind,
@@ -1157,7 +1157,7 @@ editor3_new_eid(void *baton,
                 apr_pool_t *scratch_pool)
 {
   ev3_from_delta_baton_t *eb = baton;
-  int eid = svn_branch_txn_new_eid(eb->edited_rev_root);
+  int eid = svn_branch_txn_new_eid(eb->txn);
 
   *eid_p = eid;
   return SVN_NO_ERROR;
@@ -1181,9 +1181,8 @@ editor3_open_branch(void *baton,
   *new_branch_id_p
     = svn_branch_id_nest(outer_branch_id, outer_eid, result_pool);
   new_branch
-    = svn_branch_revision_root_get_branch_by_id(eb->edited_rev_root,
-                                                *new_branch_id_p,
-                                                scratch_pool);
+    = svn_branch_txn_get_branch_by_id(eb->txn, *new_branch_id_p,
+                                      scratch_pool);
   if (new_branch)
     {
       SVN_ERR_ASSERT(root_eid == svn_branch_root_eid(new_branch));
@@ -1191,7 +1190,7 @@ editor3_open_branch(void *baton,
     }
 
   new_branch = svn_branch_add_new_branch(*new_branch_id_p,
-                                         eb->edited_rev_root,
+                                         eb->txn,
                                          predecessor,
                                          root_eid, scratch_pool);
   return SVN_NO_ERROR;
@@ -1229,7 +1228,7 @@ editor3_branch(void *baton,
     = svn_branch_id_nest(outer_branch_id, outer_eid, result_pool);
   predecessor = svn_branch_rev_bid_create(from->rev, from->bid, scratch_pool);
   new_branch = svn_branch_add_new_branch(*new_branch_id_p,
-                                         eb->edited_rev_root,
+                                         eb->txn,
                                          predecessor,
                                          from->eid, scratch_pool);
 
@@ -1252,15 +1251,14 @@ editor3_alter(void *baton,
 {
   ev3_from_delta_baton_t *eb = baton;
   svn_branch_state_t *branch
-    = svn_branch_revision_root_get_branch_by_id(eb->edited_rev_root,
-                                                branch_id, scratch_pool);
+    = svn_branch_txn_get_branch_by_id(eb->txn, branch_id, scratch_pool);
 
   /* ### Ensure the requested EIDs are allocated... This is not the
          right way to do it. Instead the Editor should map 'to be
          created' EIDs to new EIDs? See BRANCH-README. */
-  while (eid < eb->edited_rev_root->first_eid
-         || (new_parent_eid < eb->edited_rev_root->first_eid))
-    svn_branch_txn_new_eid(eb->edited_rev_root);
+  while (eid < eb->txn->first_eid
+         || (new_parent_eid < eb->txn->first_eid))
+    svn_branch_txn_new_eid(eb->txn);
 
   if (! new_payload->is_subbranch_root)
     {
@@ -1363,8 +1361,7 @@ editor3_copy_tree(void *baton,
   svn_branch_state_t *src_branch;
   svn_branch_el_rev_id_t *from_el_rev;
   svn_branch_state_t *to_branch
-    = svn_branch_revision_root_get_branch_by_id(eb->edited_rev_root,
-                                                to_branch_id, scratch_pool);
+    = svn_branch_txn_get_branch_by_id(eb->txn, to_branch_id, scratch_pool);
 
   SVN_DBG(("copy_tree(e%d -> e%d/%s)",
            src_el_rev->eid, new_parent_eid, new_name));
@@ -1388,8 +1385,7 @@ editor3_delete(void *baton,
 {
   ev3_from_delta_baton_t *eb = baton;
   svn_branch_state_t *branch
-    = svn_branch_revision_root_get_branch_by_id(eb->edited_rev_root,
-                                                branch_id, scratch_pool);
+    = svn_branch_txn_get_branch_by_id(eb->txn, branch_id, scratch_pool);
 
   SVN_DBG(("delete(b%s e%d)",
            svn_branch_get_id(branch, scratch_pool), eid));
@@ -1428,7 +1424,7 @@ convert_branch_to_paths(apr_hash_t *path
       if (! ba
           || eid == svn_branch_root_eid(branch))
         {
-          ba = svn_branch_el_rev_id_create(branch, eid, branch->rev_root->rev,
+          ba = svn_branch_el_rev_id_create(branch, eid, branch->txn->rev,
                                            result_pool);
           svn_hash_sets(paths, rrpath, ba);
           /*SVN_DBG(("branch-to-path[%d]: b%s e%d -> %s",
@@ -1524,7 +1520,7 @@ get_copy_from(svn_pathrev_t *copyfrom_pa
   if (final_payload->branch_ref.branch_id)
     {
       SVN_ERR(payload_get_storage_pathrev(copyfrom_pathrev_p, final_payload,
-                                          eb->edited_rev_root->repos,
+                                          eb->txn->repos,
                                           result_pool));
     }
   else
@@ -1640,7 +1636,7 @@ drive_changes_r(const char *rrpath,
       svn_branch_el_rev_id_t *pred_el_rev;
 
       SVN_ERR(svn_branch_repos_find_el_rev_by_path_rev(&pred_el_rev,
-                                            eb->edited_rev_root->repos,
+                                            eb->txn->repos,
                                             pred_loc->rev,
                                             top_branch_id,
                                             pred_loc->relpath,
@@ -1829,8 +1825,7 @@ drive_changes(ev3_from_delta_baton_t *eb
    */
 
   /* Process one hierarchy of nested branches at a time. */
-  branches = svn_branch_revision_root_get_branches(eb->edited_rev_root,
-                                                   scratch_pool);
+  branches = svn_branch_txn_get_branches(eb->txn, scratch_pool);
   for (i = 0; i < branches->nelts; i++)
     {
       svn_branch_state_t *root_branch = APR_ARRAY_IDX(branches, i, void *);
@@ -1846,8 +1841,8 @@ drive_changes(ev3_from_delta_baton_t *eb
         continue;  /* that's not a root branch */
 
       SVN_ERR(svn_branch_repos_get_branch_by_id(&base_root_branch,
-                                                eb->edited_rev_root->repos,
-                                                eb->edited_rev_root->base_rev,
+                                                eb->txn->repos,
+                                                eb->txn->base_rev,
                                                 root_branch->bid, scratch_pool));
       branch_is_new = !base_root_branch;
 
@@ -1856,7 +1851,7 @@ drive_changes(ev3_from_delta_baton_t *eb
                                 root_branch,
                                 scratch_pool, scratch_pool);
 
-      current.rev = eb->edited_rev_root->base_rev;
+      current.rev = eb->txn->base_rev;
       current.relpath = top_path;
 
       /* Create the top-level storage node if the branch is new, or if this is
@@ -1910,8 +1905,7 @@ editor3_sequence_point(void *baton,
   apr_array_header_t *branches;
   int i;
 
-  branches = svn_branch_revision_root_get_branches(eb->edited_rev_root,
-                                                   scratch_pool);
+  branches = svn_branch_txn_get_branches(eb->txn, scratch_pool);
 
   /* first, purge elements in each branch */
   for (i = 0; i < branches->nelts; i++)
@@ -1934,7 +1928,7 @@ editor3_sequence_point(void *baton,
       if (outer_branch
           && ! svn_branch_get_element(outer_branch, outer_eid))
         {
-          svn_branch_revision_root_delete_branch(b->rev_root, b, scratch_pool);
+          svn_branch_txn_delete_branch(b->txn, b, scratch_pool);
         }
     }
 
@@ -1951,7 +1945,7 @@ editor3_complete(void *baton,
 
   /* Convert the transaction to a revision */
   SVN_ERR(editor3_sequence_point(baton, scratch_pool));
-  SVN_ERR(svn_branch_txn_finalize_eids(eb->edited_rev_root, scratch_pool));
+  SVN_ERR(svn_branch_txn_finalize_eids(eb->txn, scratch_pool));
 
   err = drive_changes(eb, scratch_pool);
 
@@ -2046,7 +2040,7 @@ wrap_fetch_func(svn_node_kind_t *kind,
 
 svn_error_t *
 svn_editor3_in_memory(svn_editor3_t **editor_p,
-                      svn_branch_revision_root_t *branching_txn,
+                      svn_branch_txn_t *branching_txn,
                       svn_editor3__shim_fetch_func_t fetch_func,
                       void *fetch_baton,
                       apr_pool_t *result_pool)
@@ -2070,7 +2064,7 @@ svn_editor3_in_memory(svn_editor3_t **ed
   *editor_p = svn_editor3_create(&editor_funcs, eb,
                                  NULL, NULL /*cancel*/, result_pool);
 
-  eb->edited_rev_root = branching_txn;
+  eb->txn = branching_txn;
 
   wb->fetch_func = fetch_func;
   wb->fetch_baton = fetch_baton;
@@ -2086,7 +2080,7 @@ svn_editor3__ev3_from_delta_for_commit(
                         svn_editor3__shim_connector_t **shim_connector,
                         const svn_delta_editor_t *deditor,
                         void *dedit_baton,
-                        svn_branch_revision_root_t *branching_txn,
+                        svn_branch_txn_t *branching_txn,
                         const char *repos_root_url,
                         svn_editor3__shim_fetch_func_t fetch_func,
                         void *fetch_baton,
@@ -2128,7 +2122,7 @@ svn_editor3__ev3_from_delta_for_commit(
   *editor_p = svn_editor3_create(&editor_funcs, eb,
                                  cancel_func, cancel_baton, result_pool);
 
-  eb->edited_rev_root = branching_txn;
+  eb->txn = branching_txn;
 
   if (shim_connector)
     {
@@ -2156,7 +2150,7 @@ svn_editor3__ev3_from_delta_for_update(
                         svn_update_editor3_t **update_editor_p,
                         const svn_delta_editor_t *deditor,
                         void *dedit_baton,
-                        svn_branch_revision_root_t *branching_txn,
+                        svn_branch_txn_t *branching_txn,
                         const char *repos_root_url,
                         const char *base_repos_relpath,
                         svn_editor3__shim_fetch_func_t fetch_func,

Modified: subversion/branches/move-tracking-2/subversion/libsvn_ra/ra_loader.c
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/libsvn_ra/ra_loader.c?rev=1708966&r1=1708965&r2=1708966&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/libsvn_ra/ra_loader.c (original)
+++ subversion/branches/move-tracking-2/subversion/libsvn_ra/ra_loader.c Fri Oct 16 11:54:13 2015
@@ -678,7 +678,7 @@ write_rev_prop(svn_ra_session_t *ra_sess
  * branch-tracking metadata from the repository into it.
  */
 static svn_error_t *
-svn_branch_revision_fetch_info(svn_branch_revision_root_t **rev_root_p,
+svn_branch_revision_fetch_info(svn_branch_txn_t **txn_p,
                                svn_branch_repos_t *repos,
                                svn_ra_session_t *ra_session,
                                const char *branch_info_dir,
@@ -688,7 +688,7 @@ svn_branch_revision_fetch_info(svn_branc
 {
   svn_string_t *value;
   svn_stream_t *stream;
-  svn_branch_revision_root_t *rev_root;
+  svn_branch_txn_t *txn;
 
   SVN_ERR_ASSERT(SVN_IS_VALID_REVNUM(revision));
 
@@ -706,23 +706,22 @@ svn_branch_revision_fetch_info(svn_branc
   SVN_ERR_ASSERT(value);
   stream = svn_stream_from_string(value, scratch_pool);
 
-  SVN_ERR(svn_branch_revision_root_parse(&rev_root, repos, stream,
-                                         result_pool, scratch_pool));
+  SVN_ERR(svn_branch_txn_parse(&txn, repos, stream,
+                               result_pool, scratch_pool));
 
   /* Self-test: writing out the info should produce exactly the same string. */
   {
     svn_stringbuf_t *buf = svn_stringbuf_create_empty(scratch_pool);
 
     stream = svn_stream_from_stringbuf(buf, scratch_pool);
-    SVN_ERR(svn_branch_revision_root_serialize(stream, rev_root,
-                                               scratch_pool));
+    SVN_ERR(svn_branch_txn_serialize(stream, txn, scratch_pool));
     SVN_ERR(svn_stream_close(stream));
 
     SVN_ERR_ASSERT(svn_string_compare(value,
                                       svn_stringbuf__morph_into_string(buf)));
   }
 
-  *rev_root_p = rev_root;
+  *txn_p = txn;
   return SVN_NO_ERROR;
 }
 
@@ -745,13 +744,13 @@ svn_branch_repos_fetch_info(svn_branch_r
 
   for (r = 0; r <= base_revision; r++)
     {
-      svn_branch_revision_root_t *rev_root;
+      svn_branch_txn_t *txn;
 
-      SVN_ERR(svn_branch_revision_fetch_info(&rev_root,
+      SVN_ERR(svn_branch_revision_fetch_info(&txn,
                                              repos, ra_session, branch_info_dir,
                                              r,
                                              result_pool, scratch_pool));
-      SVN_ERR(svn_branch_repos_add_revision(repos, rev_root));
+      SVN_ERR(svn_branch_repos_add_revision(repos, txn));
     }
 
   *repos_p = repos;
@@ -761,7 +760,7 @@ svn_branch_repos_fetch_info(svn_branch_r
 /* Return a mutable state based on revision BASE_REVISION in REPOS.
  */
 static svn_error_t *
-svn_branch_get_mutable_state(svn_branch_revision_root_t **rev_root_p,
+svn_branch_get_mutable_state(svn_branch_txn_t **txn_p,
                              svn_branch_repos_t *repos,
                              svn_ra_session_t *ra_session,
                              const char *branch_info_dir,
@@ -769,7 +768,7 @@ svn_branch_get_mutable_state(svn_branch_
                              apr_pool_t *result_pool,
                              apr_pool_t *scratch_pool)
 {
-  svn_branch_revision_root_t *txn;
+  svn_branch_txn_t *txn;
   apr_array_header_t *branches;
   int i;
 
@@ -786,7 +785,7 @@ svn_branch_get_mutable_state(svn_branch_
   txn->base_rev = base_revision;
   txn->rev = SVN_INVALID_REVNUM;
 
-  branches = svn_branch_revision_root_get_branches(txn, scratch_pool);
+  branches = svn_branch_txn_get_branches(txn, scratch_pool);
   for (i = 0; i < branches->nelts; i++)
     {
       svn_branch_state_t *b = APR_ARRAY_IDX(branches, i, void *);
@@ -797,15 +796,15 @@ svn_branch_get_mutable_state(svn_branch_
                                     result_pool);
     }
 
-  *rev_root_p = txn;
+  *txn_p = txn;
   return SVN_NO_ERROR;
 }
 
-/* Store the move-tracking / branch-tracking metadata from REV_ROOT into the
- * repository. REV_ROOT->rev is the newly committed revision number.
+/* Store the move-tracking / branch-tracking metadata from TXN into the
+ * repository. TXN->rev is the newly committed revision number.
  */
 static svn_error_t *
-store_repos_info(svn_branch_revision_root_t *rev_root,
+store_repos_info(svn_branch_txn_t *txn,
                  svn_ra_session_t *ra_session,
                  const char *branch_info_dir,
                  apr_pool_t *scratch_pool)
@@ -813,11 +812,11 @@ store_repos_info(svn_branch_revision_roo
   svn_stringbuf_t *buf = svn_stringbuf_create_empty(scratch_pool);
   svn_stream_t *stream = svn_stream_from_stringbuf(buf, scratch_pool);
 
-  SVN_ERR(svn_branch_revision_root_serialize(stream, rev_root, scratch_pool));
+  SVN_ERR(svn_branch_txn_serialize(stream, txn, scratch_pool));
 
   SVN_ERR(svn_stream_close(stream));
   /*SVN_DBG(("store_repos_info: %s", buf->data));*/
-  SVN_ERR(write_rev_prop(ra_session, branch_info_dir, rev_root->rev,
+  SVN_ERR(write_rev_prop(ra_session, branch_info_dir, txn->rev,
                          svn_stringbuf__morph_into_string(buf), scratch_pool));
 
   return SVN_NO_ERROR;
@@ -830,7 +829,7 @@ struct ccw_baton
 
   svn_ra_session_t *session;
   const char *branch_info_dir;
-  svn_branch_revision_root_t *branching_txn;
+  svn_branch_txn_t *branching_txn;
 };
 
 /* Wrapper which stores the branching/move-tracking info.
@@ -870,7 +869,7 @@ static void
 remap_commit_callback(svn_commit_callback2_t *callback,
                       void **callback_baton,
                       svn_ra_session_t *session,
-                      svn_branch_revision_root_t *branching_txn,
+                      svn_branch_txn_t *branching_txn,
                       const char *branch_info_dir,
                       svn_commit_callback2_t original_callback,
                       void *original_baton,
@@ -967,7 +966,7 @@ svn_ra_fetch(svn_node_kind_t *kind_p,
 }
 
 svn_error_t *
-svn_ra_load_branching_state(svn_branch_revision_root_t **branching_txn_p,
+svn_ra_load_branching_state(svn_branch_txn_t **branching_txn_p,
                             svn_editor3__shim_fetch_func_t *fetch_func,
                             void **fetch_baton,
                             svn_ra_session_t *session,
@@ -1008,7 +1007,7 @@ svn_ra_load_branching_state(svn_branch_r
 
 svn_error_t *
 svn_ra_get_commit_editor_ev3(svn_ra_session_t *session,
-                             svn_branch_revision_root_t **edit_txn_p,
+                             svn_branch_txn_t **edit_txn_p,
                              svn_editor3_t **editor,
                              apr_hash_t *revprop_table,
                              svn_commit_callback2_t commit_callback,
@@ -1018,7 +1017,7 @@ svn_ra_get_commit_editor_ev3(svn_ra_sess
                              const char *branch_info_dir,
                              apr_pool_t *pool)
 {
-  svn_branch_revision_root_t *branching_txn;
+  svn_branch_txn_t *branching_txn;
   svn_editor3__shim_fetch_func_t fetch_func;
   void *fetch_baton;
   const svn_delta_editor_t *deditor;

Modified: subversion/branches/move-tracking-2/subversion/svnmover/svnmover.c
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/svnmover/svnmover.c?rev=1708966&r1=1708965&r2=1708966&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/svnmover/svnmover.c (original)
+++ subversion/branches/move-tracking-2/subversion/svnmover/svnmover.c Fri Oct 16 11:54:13 2015
@@ -161,10 +161,10 @@ wc_checkout(svnmover_wc_t *wc,
             apr_pool_t *scratch_pool)
 {
   const char *branch_info_dir = NULL;
-  svn_branch_revision_root_t *edit_txn;
+  svn_branch_txn_t *edit_txn;
   svn_editor3__shim_fetch_func_t fetch_func;
   void *fetch_baton;
-  svn_branch_revision_root_t *base_txn;
+  svn_branch_txn_t *base_txn;
 
   /* Validate and store the new base revision number */
   if (! SVN_IS_VALID_REVNUM(base_revision))
@@ -200,8 +200,8 @@ wc_checkout(svnmover_wc_t *wc,
   wc->base->revision = base_revision;
   wc->base->branch_id = apr_pstrdup(wc->pool, base_branch_id);
   wc->base->branch
-    = svn_branch_revision_root_get_branch_by_id(base_txn, wc->base->branch_id,
-                                                scratch_pool);
+    = svn_branch_txn_get_branch_by_id(base_txn, wc->base->branch_id,
+                                      scratch_pool);
   if (! wc->base->branch)
     return svn_error_createf(SVN_ERR_BRANCHING, NULL,
                              "Cannot check out WC: branch %s not found in r%ld",
@@ -211,8 +211,8 @@ wc_checkout(svnmover_wc_t *wc,
   wc->working->revision = SVN_INVALID_REVNUM;
   wc->working->branch_id = wc->base->branch_id;
   wc->working->branch
-    = svn_branch_revision_root_get_branch_by_id(edit_txn, wc->working->branch_id,
-                                                scratch_pool);
+    = svn_branch_txn_get_branch_by_id(edit_txn, wc->working->branch_id,
+                                      scratch_pool);
   SVN_ERR_ASSERT(wc->working->branch);
 
   SVN_ERR(svn_editor3_in_memory(&wc->editor,
@@ -500,7 +500,7 @@ commit_callback(const svn_commit_info_t
 /* Baton for commit_callback(). */
 typedef struct commit_callback_baton_t
 {
-  svn_branch_revision_root_t *edit_txn;
+  svn_branch_txn_t *edit_txn;
   const char *wc_base_branch_id;
   const char *wc_commit_branch_id;
   svn_editor3_t *editor;
@@ -538,7 +538,7 @@ wc_commit(svn_revnum_t *new_rev_p,
           apr_pool_t *scratch_pool)
 {
   const char *branch_info_dir = NULL;
-  svn_branch_revision_root_t *commit_txn;
+  svn_branch_txn_t *commit_txn;
   svn_editor3_t *commit_editor;
   commit_callback_baton_t ccbb;
   svn_boolean_t change_detected;
@@ -582,7 +582,7 @@ wc_commit(svn_revnum_t *new_rev_p,
   /*SVN_ERR(svn_editor3__get_debug_editor(&wc->editor, wc->editor, scratch_pool));*/
 
   edit_root_branch_id = wc->working->branch_id;
-  edit_root_branch = svn_branch_revision_root_get_branch_by_id(
+  edit_root_branch = svn_branch_txn_get_branch_by_id(
                        commit_txn, wc->working->branch_id, scratch_pool);
 
   /* We might be creating a new top-level branch in this commit. That is the
@@ -600,7 +600,7 @@ wc_commit(svn_revnum_t *new_rev_p,
 
       SVN_ERR(do_topbranch(&edit_root_branch_id, commit_editor,
                            from, scratch_pool, scratch_pool));
-      edit_root_branch = svn_branch_revision_root_get_branch_by_id(
+      edit_root_branch = svn_branch_txn_get_branch_by_id(
                            commit_txn, edit_root_branch_id, scratch_pool);
     }
   SVN_ERR(replay(commit_editor,
@@ -778,7 +778,7 @@ find_el_rev_by_rrpath_rev(svn_branch_el_
 {
   if (SVN_IS_VALID_REVNUM(revnum))
     {
-      const svn_branch_repos_t *repos = wc->working->branch->rev_root->repos;
+      const svn_branch_repos_t *repos = wc->working->branch->txn->repos;
 
       if (! branch_id)
         branch_id = wc->base->branch_id;
@@ -792,8 +792,8 @@ find_el_rev_by_rrpath_rev(svn_branch_el_
   else
     {
       svn_branch_state_t *branch
-        = branch_id ? svn_branch_revision_root_get_branch_by_id(
-                        wc->working->branch->rev_root, branch_id, scratch_pool)
+        = branch_id ? svn_branch_txn_get_branch_by_id(
+                        wc->working->branch->txn, branch_id, scratch_pool)
                     : wc->working->branch;
       svn_branch_el_rev_id_t *el_rev = apr_palloc(result_pool, sizeof(*el_rev));
 
@@ -1060,7 +1060,7 @@ list_branch(svn_branch_state_t *branch,
  * If WITH_ELEMENTS is true, also list the elements in each branch.
  */
 static svn_error_t *
-list_branches(svn_branch_revision_root_t *rev_root,
+list_branches(svn_branch_txn_t *txn,
               int eid,
               svn_boolean_t with_elements,
               apr_pool_t *scratch_pool)
@@ -1071,7 +1071,7 @@ list_branches(svn_branch_revision_root_t
 
   notify_v("%s", branch_id_header_str("  ", scratch_pool));
 
-  branches = svn_branch_revision_root_get_branches(rev_root, scratch_pool);
+  branches = svn_branch_txn_get_branches(txn, scratch_pool);
 
   for (SVN_ARRAY_ITER(bi, branches, scratch_pool))
     {
@@ -1113,14 +1113,14 @@ list_branches(svn_branch_revision_root_t
  * in each branch.
  */
 static svn_error_t *
-list_all_branches(svn_branch_revision_root_t *rev_root,
+list_all_branches(svn_branch_txn_t *txn,
                   svn_boolean_t with_elements,
                   apr_pool_t *scratch_pool)
 {
   const apr_array_header_t *branches;
   SVN_ITER_T(svn_branch_state_t) *bi;
 
-  branches = svn_branch_revision_root_get_branches(rev_root, scratch_pool);
+  branches = svn_branch_txn_get_branches(txn, scratch_pool);
 
   notify_v("branches:");
 
@@ -1423,7 +1423,7 @@ merge_subbranch(svn_editor3_t *editor,
   else if (subbr_src)  /* added on source branch */
     {
       svn_branch_rev_bid_eid_t *from
-        = svn_branch_rev_bid_eid_create(src_subbranch->rev_root->rev,
+        = svn_branch_rev_bid_eid_create(src_subbranch->txn->rev,
                                         svn_branch_get_id(src_subbranch,
                                                           scratch_pool),
                                         svn_branch_root_eid(src_subbranch),
@@ -1755,7 +1755,7 @@ do_switch(svnmover_wc_t *wc,
       /* Merge changes from the old into the new WC */
       yca = svn_branch_el_rev_id_create(previous_base_br,
                                         svn_branch_root_eid(previous_base_br),
-                                        previous_base_br->rev_root->rev,
+                                        previous_base_br->txn->rev,
                                         scratch_pool);
       src = svn_branch_el_rev_id_create(previous_working_br,
                                         svn_branch_root_eid(previous_working_br),
@@ -2313,7 +2313,7 @@ svn_branch_find_predecessor_el_rev(svn_b
                                    svn_branch_el_rev_id_t *old_el_rev,
                                    apr_pool_t *result_pool)
 {
-  const svn_branch_repos_t *repos = old_el_rev->branch->rev_root->repos;
+  const svn_branch_repos_t *repos = old_el_rev->branch->txn->repos;
   svn_branch_rev_bid_t *predecessor = old_el_rev->branch->predecessor;
   svn_branch_state_t *branch;
 
@@ -2327,8 +2327,8 @@ svn_branch_find_predecessor_el_rev(svn_b
      We don't want that result, so iterate until we find another revision. */
   while (predecessor->rev == old_el_rev->rev)
     {
-      branch = svn_branch_revision_root_get_branch_by_id(
-                 old_el_rev->branch->rev_root, predecessor->bid, result_pool);
+      branch = svn_branch_txn_get_branch_by_id(
+                 old_el_rev->branch->txn, predecessor->bid, result_pool);
       predecessor = branch->predecessor;
     }
 
@@ -2754,24 +2754,24 @@ static svn_error_t *
 display_diff_of_commit(const commit_callback_baton_t *ccbb,
                        apr_pool_t *scratch_pool)
 {
-  svn_branch_revision_root_t *previous_head_txn
+  svn_branch_txn_t *previous_head_txn
     = svn_branch_repos_get_base_revision_root(ccbb->edit_txn);
   svn_branch_state_t *base_branch
-    = svn_branch_revision_root_get_branch_by_id(previous_head_txn,
-                                                ccbb->wc_base_branch_id,
-                                                scratch_pool);
+    = svn_branch_txn_get_branch_by_id(previous_head_txn,
+                                      ccbb->wc_base_branch_id,
+                                      scratch_pool);
   svn_branch_state_t *committed_branch
-    = svn_branch_revision_root_get_branch_by_id(ccbb->edit_txn,
-                                                ccbb->wc_commit_branch_id,
-                                                scratch_pool);
+    = svn_branch_txn_get_branch_by_id(ccbb->edit_txn,
+                                      ccbb->wc_commit_branch_id,
+                                      scratch_pool);
   svn_branch_el_rev_id_t *el_rev_left
     = svn_branch_el_rev_id_create(base_branch, svn_branch_root_eid(base_branch),
-                                  base_branch->rev_root->rev,
+                                  base_branch->txn->rev,
                                   scratch_pool);
   svn_branch_el_rev_id_t *el_rev_right
     = svn_branch_el_rev_id_create(committed_branch,
                                   svn_branch_root_eid(committed_branch),
-                                  committed_branch->rev_root->rev,
+                                  committed_branch->txn->rev,
                                   scratch_pool);
 
   SVN_ERR(branch_diff_r(ccbb->editor,
@@ -3173,7 +3173,7 @@ execute(svnmover_wc_t *wc,
                 notify_v("branches rooted at e%d:", arg[0]->el_rev->eid);
               }
             SVN_ERR(list_branches(
-                      arg[0]->el_rev->branch->rev_root,
+                      arg[0]->el_rev->branch->txn,
                       arg[0]->el_rev->eid,
                       FALSE, iterpool));
           }
@@ -3185,15 +3185,15 @@ execute(svnmover_wc_t *wc,
               {
                 svn_stream_t *stream;
                 SVN_ERR(svn_stream_for_stdout(&stream, iterpool));
-                SVN_ERR(svn_branch_revision_root_serialize(
+                SVN_ERR(svn_branch_txn_serialize(
                           stream,
-                          wc->working->branch->rev_root,
+                          wc->working->branch->txn,
                           iterpool));
               }
             else
               {
                 /* Note: BASE_REVISION is always a real revision number, here */
-                SVN_ERR(list_all_branches(wc->working->branch->rev_root, TRUE,
+                SVN_ERR(list_all_branches(wc->working->branch->txn, TRUE,
                                           iterpool));
               }
           }
@@ -3238,8 +3238,8 @@ execute(svnmover_wc_t *wc,
             /* Switch the WC working state to this new branch */
             wc->working->branch_id = new_branch_id;
             wc->working->branch
-              = svn_branch_revision_root_get_branch_by_id(
-                  wc->working->branch->rev_root, new_branch_id, iterpool);
+              = svn_branch_txn_get_branch_by_id(
+                  wc->working->branch->txn, new_branch_id, iterpool);
           }
           break;
--- subversion/branches/move-tracking-2/subversion/include/private/svn_branch.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_branch.h Fri Oct 16 11:54:13 2015
@@ -66,7 +66,7 @@
  * - modify (not involving paths)
  *   => requires a txn
  *
  * Currently, a txn is represented by 'svn_branch_revision_root_t', with
  * 'svn_branch_state_t' for the individual branches in it. A flat tree is
  * represented by 'svn_branch_subtree_t'. But there is currently not a
  * clean separation; there is some overlap and some warts such as the
@@ -126,7 +126,7 @@ typedef struct svn_branch_repos_t svn_br
 /* A container for all the branching metadata for a specific revision (or
  * an uncommitted transaction).
  */
-typedef struct svn_branch_revision_root_t
+typedef struct svn_branch_txn_t
 {
   /* The repository in which this revision exists. */
   svn_branch_repos_t *repos;
@@ -146,27 +146,27 @@ typedef struct svn_branch_revision_root_
   /* All branches. */
   apr_array_header_t *branches;
 
-} svn_branch_revision_root_t;
+} svn_branch_txn_t;
 
 /* Create a new branching revision-info object.
  *
  * It will have no branch-roots.
  */
-svn_branch_revision_root_t *
-svn_branch_revision_root_create(svn_branch_repos_t *repos,
-                                svn_revnum_t rev,
-                                svn_revnum_t base_rev,
-                                apr_pool_t *result_pool);
+svn_branch_txn_t *
+svn_branch_txn_create(svn_branch_repos_t *repos,
+                      svn_revnum_t rev,
+                      svn_revnum_t base_rev,
+                      apr_pool_t *result_pool);
 
-/* Return all the branches in REV_ROOT.
+/* Return all the branches in TXN.
  *
  * Return an empty array if there are none.
  */
 apr_array_header_t *
-svn_branch_revision_root_get_branches(svn_branch_revision_root_t *rev_root,
-                                      apr_pool_t *result_pool);
+svn_branch_txn_get_branches(svn_branch_txn_t *txn,
+                            apr_pool_t *result_pool);
 
-/* Return the branch whose id is BRANCH_ID in REV_ROOT.
+/* Return the branch whose id is BRANCH_ID in TXN.
  *
  * Return NULL if not found.
  *
@@ -177,14 +177,14 @@ svn_branch_revision_root_get_branches(sv
  * See also: svn_branch_get_id().
  */
 svn_branch_state_t *
-svn_branch_revision_root_get_branch_by_id(const svn_branch_revision_root_t *rev_root,
-                                          const char *branch_id,
-                                          apr_pool_t *scratch_pool);
+svn_branch_txn_get_branch_by_id(const svn_branch_txn_t *txn,
+                                const char *branch_id,
+                                apr_pool_t *scratch_pool);
 
-/* Assign a new txn-scope element id in REV_ROOT.
+/* Assign a new txn-scope element id in TXN.
  */
 int
-svn_branch_txn_new_eid(svn_branch_revision_root_t *rev_root);
+svn_branch_txn_new_eid(svn_branch_txn_t *txn);
 
 /* Change txn-local EIDs (negative integers) in TXN to revision EIDs, by
  * assigning a new revision-EID (positive integer) for each one.
@@ -192,7 +192,7 @@ svn_branch_txn_new_eid(svn_branch_revisi
  * Rewrite TXN->first_eid and TXN->next_eid accordingly.
  */
 svn_error_t *
-svn_branch_txn_finalize_eids(svn_branch_revision_root_t *txn,
+svn_branch_txn_finalize_eids(svn_branch_txn_t *txn,
                              apr_pool_t *scratch_pool);
 
 /* Often, branches have the same root element. For example,
@@ -232,7 +232,7 @@ struct svn_branch_state_t
   svn_branch_rev_bid_t *predecessor;
 
   /* The revision to which this branch state belongs */
-  svn_branch_revision_root_t *rev_root;
+  svn_branch_txn_t *txn;
 
   /* EID -> svn_branch_el_rev_content_t mapping. */
   svn_element_tree_t *element_tree;
@@ -246,7 +246,7 @@ svn_branch_state_t *
 svn_branch_state_create(const char *bid,
                         svn_branch_rev_bid_t *predecessor,
                         int root_eid,
-                        svn_branch_revision_root_t *rev_root,
+                        svn_branch_txn_t *txn,
                         apr_pool_t *result_pool);
 
 /* Get the full id of branch BRANCH.
@@ -258,7 +258,7 @@ svn_branch_state_create(const char *bid,
  * current implementation it is constructed from the hierarchy of subbranch
  * root EIDs leading to the branch, but that may be changed in future.
  *
- * See also: svn_branch_revision_root_get_branch_by_id().
+ * See also: svn_branch_txn_get_branch_by_id().
  */
 const char *
 svn_branch_get_id(svn_branch_state_t *branch,
@@ -302,24 +302,23 @@ svn_branch_id_unnest(const char **outer_
 /* Create a new branch with branch id BID, with no elements
  * (not even a root element).
  *
- * Create and return a new branch object. Register its existence in REV_ROOT.
+ * Create and return a new branch object. Register its existence in TXN.
  *
  * Set the root element to ROOT_EID.
  */
 svn_branch_state_t *
 svn_branch_add_new_branch(const char *bid,
-                          svn_branch_revision_root_t *rev_root,
+                          svn_branch_txn_t *txn,
                           svn_branch_rev_bid_t *predecessor,
                           int root_eid,
                           apr_pool_t *scratch_pool);
 
-/* Remove branch BRANCH from the list of branches in REV_ROOT.
+/* Remove branch BRANCH from the list of branches in TXN.
  */
 void
-svn_branch_revision_root_delete_branch(
-                                svn_branch_revision_root_t *rev_root,
-                                svn_branch_state_t *branch,
-                                apr_pool_t *scratch_pool);
+svn_branch_txn_delete_branch(svn_branch_txn_t *txn,
+                             svn_branch_state_t *branch,
+                             apr_pool_t *scratch_pool);
 
 /* element */
 /*
@@ -517,22 +516,22 @@ svn_branch_get_eid_by_path(const svn_bra
 svn_string_t *
 svn_branch_get_default_r0_metadata(apr_pool_t *result_pool);
 
 /* Create a new revision-root object *REV_ROOT_P, initialized with info
  * parsed from STREAM, allocated in RESULT_POOL.
  */
 svn_error_t *
-svn_branch_revision_root_parse(svn_branch_revision_root_t **rev_root_p,
-                               svn_branch_repos_t *repos,
-                               svn_stream_t *stream,
-                               apr_pool_t *result_pool,
-                               apr_pool_t *scratch_pool);
+svn_branch_txn_parse(svn_branch_txn_t **txn_p,
+                     svn_branch_repos_t *repos,
+                     svn_stream_t *stream,
+                     apr_pool_t *result_pool,
+                     apr_pool_t *scratch_pool);
 
-/* Write to STREAM a parseable representation of REV_ROOT.
+/* Write to STREAM a parseable representation of TXN.
  */
 svn_error_t *
-svn_branch_revision_root_serialize(svn_stream_t *stream,
-                                   svn_branch_revision_root_t *rev_root,
-                                   apr_pool_t *scratch_pool);
+svn_branch_txn_serialize(svn_stream_t *stream,
+                         svn_branch_txn_t *txn,
+                         apr_pool_t *scratch_pool);
 
 /* Write to STREAM a parseable representation of BRANCH.
  */
@@ -66,7 +66,7 @@
  *   => requires a txn
  *
- * Currently, a txn is represented by 'svn_branch_revision_root_t', with
+ * Currently, a txn is represented by 'svn_branch_txn_t', with
  * 'svn_branch_state_t' for the individual branches in it. A flat tree is
  * represented by 'svn_branch_subtree_t'. But there is currently not a
@@ -517,22 +516,22 @@ svn_branch_get_eid_by_path(const svn_bra
 svn_branch_get_default_r0_metadata(apr_pool_t *result_pool);
 
-/* Create a new revision-root object *REV_ROOT_P, initialized with info
+/* Create a new txn object *TXN_P, initialized with info
  * parsed from STREAM, allocated in RESULT_POOL.
  */

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_branch_repos.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_branch_repos.h?rev=1708966&r1=1708965&r2=1708966&view=diff
==============================================================================